@@ -53,7 +53,7 @@ from .listeners import (  # noqa
     force_auto_coercion,
     force_instant_defaults
 )
-from .models import Timestamp  # noqa
+from .models import generic_repr, Timestamp  # noqa
 from .observer import observes  # noqa
 from .primitives import Country, Currency, Ltree, WeekDay, WeekDays  # noqa
 from .proxy_dict import proxy_dict, ProxyDict  # noqa
@@ -94,5 +94,10 @@ from .types import (  # noqa
     UUIDType,
     WeekDaysType
 )
+from .view import (  # noqa
+    create_materialized_view,
+    create_view,
+    refresh_materialized_view
+)
 
-__version__ = '0.32.9'
+__version__ = '0.33.6'
