@@ -451,10 +451,17 @@ def database_exists(url):
 
     """
 
+    def get_scalar_result(engine, sql):
+        result_proxy = engine.execute(sql)
+        result = result_proxy.scalar()
+        result_proxy.close()
+        engine.dispose()
+        return result
+
     url = copy(make_url(url))
     database = url.database
-    if url.drivername.startswith('postgresql'):
-        url.database = 'template1'
+    if url.drivername.startswith('postgres'):
+        url.database = 'postgres'
     else:
         url.database = None
 
@@ -462,12 +469,12 @@ def database_exists(url):
 
     if engine.dialect.name == 'postgresql':
         text = "SELECT 1 FROM pg_database WHERE datname='%s'" % database
-        return bool(engine.execute(text).scalar())
+        return bool(get_scalar_result(engine, text))
 
     elif engine.dialect.name == 'mysql':
         text = ("SELECT SCHEMA_NAME FROM INFORMATION_SCHEMA.SCHEMATA "
                 "WHERE SCHEMA_NAME = '%s'" % database)
-        return bool(engine.execute(text).scalar())
+        return bool(get_scalar_result(engine, text))
 
     elif engine.dialect.name == 'sqlite':
         if database:
@@ -478,15 +485,21 @@ def database_exists(url):
             return True
 
     else:
+        engine.dispose()
+        engine = None
         text = 'SELECT 1'
         try:
             url.database = database
             engine = sa.create_engine(url)
-            engine.execute(text)
+            result = engine.execute(text)
+            result.close()
             return True
 
         except (ProgrammingError, OperationalError):
             return False
+        finally:
+            if engine is not None:
+                engine.dispose()
 
 
 def create_database(url, encoding='utf8', template=None):
@@ -515,12 +528,13 @@ def create_database(url, encoding='utf8', template=None):
 
     database = url.database
 
-    if url.drivername.startswith('postgresql'):
-        url.database = 'template1'
+    if url.drivername.startswith('postgres'):
+        url.database = 'postgres'
     elif not url.drivername.startswith('sqlite'):
         url.database = None
 
     engine = sa.create_engine(url)
+    result_proxy = None
 
     if engine.dialect.name == 'postgresql':
         if engine.driver == 'psycopg2':
@@ -530,21 +544,21 @@ def create_database(url, encoding='utf8', template=None):
             )
 
         if not template:
-            template = 'template0'
+            template = 'template1'
 
         text = "CREATE DATABASE {0} ENCODING '{1}' TEMPLATE {2}".format(
             quote(engine, database),
             encoding,
             quote(engine, template)
         )
-        engine.execute(text)
+        result_proxy = engine.execute(text)
 
     elif engine.dialect.name == 'mysql':
         text = "CREATE DATABASE {0} CHARACTER SET = '{1}'".format(
             quote(engine, database),
             encoding
         )
-        engine.execute(text)
+        result_proxy = engine.execute(text)
 
     elif engine.dialect.name == 'sqlite' and database != ':memory:':
         if database:
@@ -552,7 +566,11 @@ def create_database(url, encoding='utf8', template=None):
 
     else:
         text = 'CREATE DATABASE {0}'.format(quote(engine, database))
-        engine.execute(text)
+        result_proxy = engine.execute(text)
+
+    if result_proxy is not None:
+        result_proxy.close()
+    engine.dispose()
 
 
 def drop_database(url):
@@ -572,12 +590,13 @@ def drop_database(url):
 
     database = url.database
 
-    if url.drivername.startswith('postgresql'):
-        url.database = 'template1'
+    if url.drivername.startswith('postgres'):
+        url.database = 'postgres'
     elif not url.drivername.startswith('sqlite'):
         url.database = None
 
     engine = sa.create_engine(url)
+    conn_resource = None
 
     if engine.dialect.name == 'sqlite' and database != ':memory:':
         if database:
@@ -585,17 +604,14 @@ def drop_database(url):
 
     elif engine.dialect.name == 'postgresql' and engine.driver == 'psycopg2':
         from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT
-        engine.raw_connection().set_isolation_level(ISOLATION_LEVEL_AUTOCOMMIT)
+
+        connection = engine.connect()
+        connection.connection.set_isolation_level(ISOLATION_LEVEL_AUTOCOMMIT)
 
         # Disconnect all users from the database we are dropping.
-        version = list(
-            map(
-                int,
-                engine.execute('SHOW server_version').first()[0].split('.')
-            )
-        )
+        version = connection.dialect.server_version_info
         pid_column = (
-            'pid' if (version[0] >= 9 and version[1] >= 2) else 'procpid'
+            'pid' if (version >= (9, 2)) else 'procpid'
         )
         text = '''
         SELECT pg_terminate_backend(pg_stat_activity.%(pid_column)s)
@@ -603,12 +619,16 @@ def drop_database(url):
         WHERE pg_stat_activity.datname = '%(database)s'
           AND %(pid_column)s <> pg_backend_pid();
         ''' % {'pid_column': pid_column, 'database': database}
-        engine.execute(text)
+        connection.execute(text)
 
         # Drop the database.
-        text = 'DROP DATABASE {0}'.format(quote(engine, database))
-        engine.execute(text)
-
+        text = 'DROP DATABASE {0}'.format(quote(connection, database))
+        connection.execute(text)
+        conn_resource = connection
     else:
         text = 'DROP DATABASE {0}'.format(quote(engine, database))
-        engine.execute(text)
+        conn_resource = engine.execute(text)
+
+    if conn_resource is not None:
+        conn_resource.close()
+    engine.dispose()
